@@ -25,24 +25,38 @@ import os
 from urlparse import urlparse
 from xdg import BaseDirectory
 
+###################
+# LOCAL CONSTANTS #
+###################
+
 CLIENT_ID     = "A0IJ0P4EFRO50JUEYALJDGR52RDS0O4H1OKPSIEYZ5LHSNGH"
 CLIENT_SECRET = "ACDUWAODBXRUPXHMVVWOXXATFN0PM0GP2PSLI5MZZCTUQ2TV"
 CALLBACK_URI  = "http://localhost:6060/auth"
 
-authData = dict()
-
 BASE_URL = "https://api.foursquare.com/v2/"
 API_VERSION = "20120208"
 DEBUG = False
 
-DefaultFetchAmount = 25
-
 BROADCAST_DEFAULT = "public"
 
+####################
+# GLOBAL CONSTANTS #
+####################
+
+DEFAULT_FETCH_AMOUNT = 25
+
+#########################
+# FILES AND DIRECTORIES #
+#########################
+
+# Directory that contains the cache
 cache_dir = os.path.join(BaseDirectory.xdg_cache_home, "ubersquare/")
+# Directory that contains cached images
 image_dir = os.path.join(BaseDirectory.xdg_data_home, "ubersquare/images/")
+# Directory that contains the configuration
 config_dir = os.path.join(BaseDirectory.xdg_config_home, "ubersquare/")
 
+# Create missing directories
 if not os.path.exists(cache_dir):
 	os.makedirs(cache_dir)
 if not os.path.exists(image_dir):
@@ -50,20 +64,32 @@ if not os.path.exists(image_dir):
 if not os.path.exists(config_dir):
 	os.makedirs(config_dir)
 
-query_cache = cache_dir + "cache.sqlite"
-if not os.path.exists(query_cache):
+def create_cache_db():
 	conn = sqlite3.connect(query_cache)
 	conn.execute("CREATE TABLE IF NOT EXISTS queries (resource TEXT PRIMARY KEY, value TEXT)")
-	#conn.execute("CREATE TABLE IF NOT EXISTS tips (tipId TEXT PRIMARY KEY, venueID TEXT, done BOOLEAN, todo BOOLEAN, tipText TEXT)")
 	conn.close()
 
-config = config_dir + "config.sqlite"
-if not os.path.exists(config):
+def create_config_db():
 	conn = sqlite3.connect(config)
 	conn.execute("CREATE TABLE IF NOT EXISTS config (property TEXT PRIMARY KEY, value TEXT)")
 	conn.close()
 
 
+
+query_cache = cache_dir + "cache.sqlite"
+if not os.path.exists(query_cache):
+	create_cache_db();
+
+config = config_dir + "config.sqlite"
+if not os.path.exists(config):
+	create_config_db()
+	
+authData = dict()
+
+#######################
+# AUX DEBUG FUNCTIONS #
+#######################
+
 def debug(string):
 	print string
 
@@ -71,6 +97,14 @@ def debug(string):
 def debug_json(string):
 	print json.dumps(string, sort_keys=True, indent=4)
 
+def cacheModeToString(cacheMode):
+	if cacheMode == CacheOnly:
+		return "Get from cache or return null"
+	elif cacheMode == CacheIfPosible:
+		return "Get from cache or foursquare"
+	elif cacheMode == NoCache:
+		return "Don't read from cache"
+
 ####################
 # CACHE/FOURSQUARE #
 ####################
@@ -103,7 +137,10 @@ def config_get(property):
 	return value
 
 
-# True and False are to mantain some legacy code, but *will* be deprecated.
+# All these values are used throughout the system, but the class Cache
+# should override them all, and these six fields should dissapear
+
+# Usage of True/False has to be purged everywhere as well, that's really old code!
 CacheOnly = 3
 CacheIfPosible = True
 NoCache = False
@@ -119,16 +156,10 @@ class Cache:
 	ForceFetch = False
 
 
-def cacheModeToString(cacheMode):
-	if cacheMode == CacheOnly:
-		return "Get from cache or return null"
-	elif cacheMode == CacheIfPosible:
-		return "Get from cache or foursquare"
-	elif cacheMode == NoCache:
-		return "Don't read from cache"
-
-
 def foursquare_get(path, params, read_cache=False, callback=None):
+	"""
+	Performs an HTTP get on PATH.
+	"""
 	commonParams = {'oauth_token': authData['ACCESS_TOKEN'], 'v': API_VERSION}
 	allParams = urllib.urlencode(dict(commonParams.items() + params.items()))
 
@@ -202,26 +233,31 @@ def build_venue_array(source):
 	venues = dict()
 	i = 0
 	for venue in source:
-		if u'beenHere' in venue:
+		if 'beenHere' in venue:
 			 # Dirty, but the the model is too much in use to avoid this at 4am
-			venue[u'venue'][u'beenHere'] = venue[u'beenHere']
+			venue['venue']['beenHere'] = venue['beenHere']
 		venues[i] = venue
 		i += 1
 	return venues
 
 ###############################################################################
+# All these method names need refactoring.  They should be similar to the foursquare API,
+# ie: calls to endpoint "user/$UID/tips" should be user_tips(uid)
+
+# Better still, there should be actual objects to do this;
+# users.tips(uid)
 
 
 def get_history(read_cache):
 	response = foursquare_get("users/self/venuehistory", {}, read_cache)
 	if response:
-		return build_venue_array(response[u'response'][u'venues'][u'items'])
+		return build_venue_array(response['response']['venues']['items'])
 
 
 def lists_todos(read_cache):
 	response = foursquare_get("lists/self/todos", {}, read_cache)
 	if response:
-		return build_venue_array(response[u'response'][u'list'][u'listItems'][u'items'])
+		return build_venue_array(response['response']['list']['listItems']['items'])
 
 
 def venues_search(query, ll, category, limit, read_cache):
@@ -229,10 +265,10 @@ def venues_search(query, ll, category, limit, read_cache):
 	if response:
 		venues = dict()
 		i = 0
-		for venue in response[u'response'][u'venues']:
+		for venue in response['response']['venues']:
 			# Esto puede parecer cualquiera, pero es para que tenga el mismo formato que los dem&aacute;s, y sean todas las listas iguales
 			venues[i] = dict()
-			venues[i][u'venue'] = venue
+			venues[i]['venue'] = venue
 			i += 1
 		return venues
 
@@ -243,13 +279,13 @@ def get_user(uid, read_cache):
 	"""
 	response = foursquare_get("users/" + uid, {}, read_cache)
 	if response:
-		return response[u'response']
+		return response['response']
 
 
 def get_venue(venueId):
 	response = foursquare_get("/venues/%s?" % venueId, {})
 	if response:
-		return response[u'response'][u'venue']
+		return response['response']['venue']
 
 
 # TODO: make this entire file OO, and this an actual attribute of it
@@ -265,7 +301,7 @@ def checkin(venue, ll, shout="", broadcast=None):
 
 	print "Checking in with broadcast = " + broadcast
 
-	response = foursquare_post("/checkins/add", {'shout': shout, 'venueId': venue[u'id'], 'broadcast': broadcast, 'll': ll})
+	response = foursquare_post("/checkins/add", {'shout': shout, 'venueId': venue['id'], 'broadcast': broadcast, 'll': ll})
 
 	# This is, without doubt, the nastiest hack I've ever done!
 	print len(checkin_hooks)
@@ -284,10 +320,10 @@ def get_last_ll():
 	Returns the ll of the user's last checkin
 	"""
 	ll = dict()
-	for item in get_user("self", False)[u'user'][u'checkins'][u'items']:
-		if item[u'type'] == "checkin":
-			ll['lat'] = item[u'venue'][u'location'][u'lat']
-			ll['lng'] = item[u'venue'][u'location'][u'lng']
+	for item in get_user("self", False)['user']['checkins']['items']:
+		if item['type'] == "checkin":
+			ll['lat'] = item['venue']['location']['lat']
+			ll['lng'] = item['venue']['location']['lng']
 	if 'lat' in ll:
 		ll = "%(lat)2.6f,%(lng)2.6f" % ll
 	else:
@@ -303,13 +339,13 @@ def get_venues_categories(readCache=CacheOrGet):
 	"""
 	response = foursquare_get("venues/categories", {}, readCache)
 	if response:
-		return response[u'response'][u'categories']
+		return response['response']['categories']
 
 
 def venue_add(venue, ignoreDuplicates=False, ignoreDuplicatesKey=None):
 	"""
 	required: name, ll
-	optional: address, crossAddress, city, state, zip, phone, twitter, primaryCategoryId, description, url
+	optional: address, crossStreet, city, state, zip, phone, twitter, primaryCategoryId, description, url
 	second_run: ignoreDuplicates, ignoreDuplicatesKey
 	"""
 	response = foursquare_post("venues/add", venue)
@@ -320,13 +356,13 @@ def venues_venue(venueId, readCache=CacheIfPosible):
 	response = foursquare_get("venues/" + venueId, {}, readCache)
 	if response:
 		#response > venue > tips > groups [] > items [] >
-		return response[u'response'][u'venue']
+		return response['response']['venue']
 
 
 def users_leaderboard(read_cache):
 	response = foursquare_get("users/leaderboard", {}, read_cache)
 	if response:
-		return response[u'response'][u'leaderboard'][u'items']
+		return response['response']['leaderboard']['items']
 
 
 def __delete_venue_with_tip(tipId):
@@ -367,17 +403,22 @@ def tip_markdone(tipId, marked):
 	__delete_venue_with_tip(tipId)
 	return response
 
+def user_mayorships(userId, read_cache):
+	response = foursquare_get("users/" + userId + "/mayorships", {}, read_cache)
+	if response:
+		return build_venue_array(response['response']['mayorships']['items'])
+
 ############################
 # Extra one-time functions #
 ############################
 
 
 def fetch_category_image(category):
-	prefix = category[u'icon'][u'prefix']
-	extension = category[u'icon'][u'name']
+	prefix = category['icon']['prefix']
+	extension = category['icon']['name']
 	image(prefix + "64" + extension)
-	if u'categories' in category:
-		for category in category[u'categories']:
+	if 'categories' in category:
+		for category in category['categories']:
 			fetch_category_image(category)
 
 
@@ -393,7 +434,7 @@ def init():
 	authData['ACCESS_TOKEN'] = config_get("access_token")
 
 if __name__ == "__main__":
-	print "This is the foursquare API library, you're not supposed to run this!"
-	sys.exit()
+	print "This is the foursquare API library, yo're not supposed to run this!"
+	sys.exit(0)
 else:
 	init()
